/*
 * who.c -- part of botnetop.mod
 *
 * $Id$
 */
/* 
 * Copyright (C) 2000  Teemu Hjelt <temex@iki.fi>
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

static struct who_t *find_who(char *nick)
{
  struct who_t *w = start_who;

  while (w) {
    if (!rfc_casecmp(w->nick, nick))
      return w;
    w = w->next;
  }
  return NULL;
}

static struct who_t *add_who(char *nick, char *chan, char *bot, char *uhost)
{
  struct who_t *w;

  w = (struct who_t *) nmalloc(sizeof(struct who_t));
  w->next = NULL;
  if (start_who == NULL)
    start_who = w;
  else if (prev_who != NULL)
    prev_who->next = w;
  prev_who = w;
  strncpy(w->nick, nick, sizeof(w->nick) - 1);
  strncpy(w->chan, chan, sizeof(w->chan) - 1);
  strncpy(w->bot, bot, sizeof(w->bot) - 1);
  strncpy(w->uhost, uhost, sizeof(w->uhost) - 1);
  putlog(LOG_DEBUG, "*", "botnetop.mod: new who record created for %s (address: %u)", nick, w);
  return w;
}

static void del_who(char *nick)
{
  struct who_t *w = start_who, *wnext;

  if (start_who != NULL) {
    if (!rfc_casecmp(start_who->nick, nick)) {
      start_who = w->next;
      nfree(w);
      putlog(LOG_DEBUG, "*", "botnetop.mod: deleted first who record from %s\n", nick);
    } else {
      while (w->next) {
        wnext = w->next;
        if (!rfc_casecmp(wnext->nick, nick)) {
          w->next = wnext->next;
          nfree(wnext);
          putlog(LOG_DEBUG, "*", "botnetop.mod: deleted who record from %s", nick);
        }
        w = w->next;
      }
    }
  }
}

static void who_free_mem()
{
  struct who_t *w = start_who, *wnext;

  while (w) {
    wnext = w->next;
    nfree(w);
    w = wnext;
  }
  start_who = NULL;
}
